#include <stdio.h>
#include <stdint.h>
#include <stdlib.h>
#include <stdbool.h>
#include <string.h>
#include <assert.h>

#define DECIMALS_PER_DIGIT 18
#define BASE 1000000000000000000
#define DIGITS_LEN 56

struct Big_Int {
    uint64_t digits[DIGITS_LEN+1];
};

bool cmp_big_small(const struct Big_Int *a, const uint64_t b) {
    if (a->digits[0] != b) return false;
    for (int64_t i = 1; i < DIGITS_LEN; ++i) {
        if (a->digits[i] != 0) return false;
    }
    return true;
}

struct Big_Int add(const struct Big_Int *a, const struct Big_Int *b) {
    struct Big_Int ret;
    memset(ret.digits, 0, sizeof(uint64_t)*DIGITS_LEN);

    for (int64_t i = 0; i < DIGITS_LEN; ++i) {
        ret.digits[i] += a->digits[i] + b->digits[i];

        if (i + 1 < DIGITS_LEN && ret.digits[i] >= BASE) {
            ret.digits[i] -= BASE;
            ++ret.digits[i+1];
        }
    }

    return ret;
}

void print(const struct Big_Int *a) {
    int64_t idx = DIGITS_LEN - 1;
    while (a->digits[idx] == 0) --idx;
    for (; idx >= 0; --idx) printf("%018llu", a->digits[idx]);
    printf("\n");
}

bool even(const struct Big_Int *a) {
    return a->digits[0] % 2 == 0;
}

// This assumes an even base
struct Big_Int half(const struct Big_Int *a) {
    struct Big_Int ret;
    memcpy(&ret, a, sizeof(ret));

    for (int64_t i = DIGITS_LEN-1; i >= 0; --i) {
        if (i > 0 && ret.digits[i] % 2 == 1) ret.digits[i-1] += BASE;
        ret.digits[i] >>= 1;
    }

    return ret;
}

struct Big_Int dec(const struct Big_Int *a) {
    struct Big_Int ret;
    memcpy(&ret, a, sizeof(ret));

    int64_t first_nonzero = 0;
    while (ret.digits[first_nonzero] == 0 && first_nonzero < DIGITS_LEN) ++first_nonzero;
    assert(first_nonzero < DIGITS_LEN);

    ret.digits[first_nonzero]--;
    for (int64_t i = 0; i < first_nonzero; ++i) ret.digits[i] = BASE - 1;

    return ret;
}

struct Big_Int mul(const struct Big_Int *a, const struct Big_Int *b) {
    if (cmp_big_small(b, 1)) return *a;
    if (even(b)) {
        const struct Big_Int half_b = half(b);
        const struct Big_Int half_ret = mul(a, &half_b);
        return add(&half_ret, &half_ret);
    }
    const struct Big_Int dec_b = dec(b);
    const struct Big_Int ret_minus_a = mul(a, &dec_b);
    return add(&ret_minus_a, a);
}

struct Big_Int big_pow(const struct Big_Int *a, const struct Big_Int *b) {
    if (cmp_big_small(b, 1)) return *a;
    if (even(b)) {
        const struct Big_Int half_b = half(b);
        const struct Big_Int sqrt_ret = big_pow(a, &half_b);
        return mul(&sqrt_ret, &sqrt_ret);
    }
    const struct Big_Int dec_b = dec(b);
    const struct Big_Int ret_div_a = big_pow(a, &dec_b);
    return mul(&ret_div_a, a);
}

uint64_t get_digit(const struct Big_Int *a, uint64_t k) {
    int64_t idx = k / DECIMALS_PER_DIGIT;
    k %= DECIMALS_PER_DIGIT;

    int64_t div = 1;
    for (int i = 0; i < k; ++i) div *= 10;

    return (a->digits[idx] / div) % 10;
}

int main () {
    struct Big_Int a;
    struct Big_Int b;
    uint64_t k;

    uint64_t t;
    scanf("%llu", &t);
    for (int i = 0; i < t; ++i) {
        memset(a.digits, 0, sizeof(uint64_t)*DIGITS_LEN);
        memset(b.digits, 0, sizeof(uint64_t)*DIGITS_LEN);

        scanf("%llu%llu%llu", &a.digits[0], &b.digits[0], &k);
        if (a.digits[0] >= BASE) {
            a.digits[0] -= BASE;
            ++a.digits[1];
        }
        if (b.digits[0] >= BASE) {
            b.digits[0] -= BASE;
            ++b.digits[1];
        }

        struct Big_Int c = big_pow(&a, &b);
        --k;

        printf("%llu\n", get_digit(&c, k));
    }
}
